@@ -21,10 +21,8 @@ from testtools.matchers import (
     Is,
     KeysEqual,
     MatchesDict,
-    MatchesException,
     MatchesListwise,
     Not,
-    Raises,
     )
 from testtools.runtest import RunTest
 from testtools.testresult.doubles import ExtendedTestResult
@@ -804,7 +802,7 @@ class TestAssertFailsWith(NeedsTwistedTestCase):
             failure.trap(self.failureException)
             self.assertThat(
                 str(failure.value),
-                Equals("RuntimeError not raised ({!r} returned)".format(marker)))
+                Equals(f"RuntimeError not raised ({marker!r} returned)"))
         d.addCallbacks(
             lambda x: self.fail("Should not have succeeded"), check_result)
         return d
@@ -867,7 +865,7 @@ class TestAssertFailsWith(NeedsTwistedTestCase):
             failure.trap(CustomException)
             self.assertThat(
                 str(failure.value),
-                Equals("RuntimeError not raised ({!r} returned)".format(marker)))
+                Equals(f"RuntimeError not raised ({marker!r} returned)"))
         return d.addCallbacks(
             lambda x: self.fail("Should not have succeeded"), check_result)
 
@@ -875,7 +873,7 @@ class TestAssertFailsWith(NeedsTwistedTestCase):
 class TestRunWithLogObservers(NeedsTwistedTestCase):
 
     def test_restores_observers(self):
-        from testtools.deferredruntest import run_with_log_observers
+        from testtools.twistedsupport._runtest import run_with_log_observers
         from twisted.python import log
         # Make sure there's at least one observer.  This reproduces bug
         # #926189.
@@ -1015,7 +1013,7 @@ class TestCaptureTwistedLogs(NeedsTwistedTestCase):
 
 
 def test_suite():
-    from unittest import TestLoader, TestSuite
+    from unittest import TestLoader
     return TestLoader().loadTestsFromName(__name__)
 
 
